==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE15S.sql <==
/****************************************************************************/
/* GE15 ( ｱｸｾｽ調査ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE15 (
   SYSTEM_ID        VARCHAR ( 10 )                  NOT NULL                                                /*  10 ｼｽﾃﾑID               */
 , USERID           VARCHAR ( 10 )                  NOT NULL                                                /*  20 ﾕｰｻﾞｰID              */
 , USERADRS         VARCHAR ( 40 )                                                                          /*  30 IPｱﾄﾞﾚｽ(local)       */
 , HOSTADRS         VARCHAR ( 40 )                                                                          /*  40 IPｱﾄﾞﾚｽ(remote)      */
 , GUIKEY           VARCHAR ( 30 )                                                                          /*  50 画面ID               */
 , DYLOGIN          VARCHAR ( 14 )                                                                          /*  60 ﾛｸﾞｲﾝ時間            */
 , DYLOGOUT         VARCHAR ( 14 )                                                                          /*  70 ﾛｸﾞｱｳﾄ時間           */
 , USED_TIME        INTEGER             DEFAULT 0   NOT NULL                                                /*  80 使用時間(秒)         */
 , CNT_ACCESS       INTEGER             DEFAULT 0   NOT NULL                                                /*  90 ｱｸｾｽ件数             */
 , CNT_ERROR        INTEGER             DEFAULT 0   NOT NULL                                                /* 100 ｴﾗｰ件数              */
 , CNT_READ         INTEGER             DEFAULT 0   NOT NULL                                                /* 110 読込件数             */
 , CNT_WRITE        INTEGER             DEFAULT 0   NOT NULL                                                /* 120 出力件数             */
 , TM_TOTAL_QUERY   BIGINT              DEFAULT 0   NOT NULL                                                /* 130 ﾄｰﾀﾙDBｸｴﾘ時間(ms)    */
 , TM_MAX_QUERY     INTEGER             DEFAULT 0   NOT NULL                                                /* 140 最大DBｸｴﾘ時間(ms)    */
 , MAX_QUERY        TEXT                                                                                    /* 150 最長実行ｸｴﾘ          */
 , UNIQ             BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              VARCHAR (  1 )      DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            VARCHAR ( 14 )                                                                          /* 820 登録日時             */
 , PGSET            VARCHAR ( 10 )                                                                          /* 830 作成PG               */
 , PGPSET           VARCHAR ( 10 )                                                                          /* 840 作成親PG             */
 , USRSET           VARCHAR ( 10 )                                                                          /* 850 作成者               */
 , DYUPD            VARCHAR ( 14 )                                                                          /* 860 更新日時             */
 , PGUPD            VARCHAR ( 10 )                                                                          /* 870 更新PG               */
 , PGPUPD           VARCHAR ( 10 )                                                                          /* 880 更新親PG             */
 , USRUPD           VARCHAR ( 10 )                                                                          /* 890 更新者               */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE15S.sql <==
/****************************************************************************/
/* GE15 ( ｱｸｾｽ調査ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:03                                            */
/****************************************************************************/

CREATE TABLE GE15 (
   SYSTEM_ID        VARCHAR ( 10 )                  NOT NULL                                                /*  10 ｼｽﾃﾑID               */
 , USERID           VARCHAR ( 10 )                  NOT NULL                                                /*  20 ﾕｰｻﾞｰID              */
 , USERADRS         VARCHAR ( 40 )                                                                          /*  30 IPｱﾄﾞﾚｽ(local)       */
 , HOSTADRS         VARCHAR ( 40 )                                                                          /*  40 IPｱﾄﾞﾚｽ(remote)      */
 , GUIKEY           VARCHAR ( 30 )                                                                          /*  50 画面ID               */
 , DYLOGIN          VARCHAR ( 14 )                                                                          /*  60 ﾛｸﾞｲﾝ時間            */
 , DYLOGOUT         VARCHAR ( 14 )                                                                          /*  70 ﾛｸﾞｱｳﾄ時間           */
 , USED_TIME        INTEGER             DEFAULT 0   NOT NULL                                                /*  80 使用時間(秒)         */
 , CNT_ACCESS       INTEGER             DEFAULT 0   NOT NULL                                                /*  90 ｱｸｾｽ件数             */
 , CNT_ERROR        INTEGER             DEFAULT 0   NOT NULL                                                /* 100 ｴﾗｰ件数              */
 , CNT_READ         INTEGER             DEFAULT 0   NOT NULL                                                /* 110 読込件数             */
 , CNT_WRITE        INTEGER             DEFAULT 0   NOT NULL                                                /* 120 出力件数             */
 , TM_TOTAL_QUERY   BIGINT              DEFAULT 0   NOT NULL                                                /* 130 ﾄｰﾀﾙDBｸｴﾘ時間(ms)    */
 , TM_MAX_QUERY     INTEGER             DEFAULT 0   NOT NULL                                                /* 140 最大DBｸｴﾘ時間(ms)    */
 , MAX_QUERY        TEXT                                                                                    /* 150 最長実行ｸｴﾘ          */
 , UNIQ             BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              VARCHAR (  1 )      DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            VARCHAR ( 14 )                                                                          /* 820 作成日時             */
 , PGSET            VARCHAR ( 10 )                                                                          /* 830 作成PG               */
 , PGPSET           VARCHAR ( 10 )                                                                          /* 840 作成親PG             */
 , USRSET           VARCHAR ( 10 )                                                                          /* 850 作成者               */
 , DYUPD            VARCHAR ( 14 )                                                                          /* 860 更新日時             */
 , PGUPD            VARCHAR ( 10 )                                                                          /* 870 更新PG               */
 , PGPUPD           VARCHAR ( 10 )                                                                          /* 880 更新親PG             */
 , USRUPD           VARCHAR ( 10 )                                                                          /* 890 更新者               */
);
